@@ -1,15 +1,14 @@
-# main 76
+# main 77
 # sam robson
 import warnings
 import cython
 import pyximport; pyximport.install()
+
 try:
-    import cal
-except:
-    try:
-        from alacorder import cal
-    except:
-        from alacorder import alac as cal
+    from alacorder import cal
+except ImportError:
+    from alacorder import alac as cal
+
 import os
 import sys
 import math
@@ -33,12 +32,12 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group()
-@click.version_option("76.8.3", package_name="alacorder")
+@click.version_option("77.3.5", package_name="alacorder")
 def cli():
     """
-    ALACORDER beta 76.8
+    ALACORDER beta 77.3
 
-    Alacorder processes case detail PDFs into data tables suitable for research purposes. Alacorder also generates compressed text archives from the source PDFs to speed future data collection from the same set of cases.
+    Alacorder retrieves case detail PDFs from Alacourt.com and processes them into text archives and data tables suitable for research purposes.
 
     """
     pass
@@ -53,7 +52,7 @@ def cli():
               help="Compress exported file (Excel files not supported)")
 @click.option('--overwrite', '-o', default=False, help="Overwrite existing files at output path", is_flag=True,show_default=False)
 @click.option('--no-prompt','-s', default=False, is_flag=True, help="Skip user input / confirmation prompts")
-@click.option('--no-batch','-b', default=False, is_flag=True, help="Process all inputs as one batch")
+@click.option('--no-batch','-b', default=True, is_flag=True, help="Process all inputs as one batch")
 @click.option('--no-log','-q','log', default=False, is_flag=True, help="Don't print logs or progress to console")
 @click.option('--no-write', default=False, is_flag=True, help="Do not export to output path", hidden=True)
 @click.option('--debug','-d', default=False, is_flag=True, help="Print extensive logs to console for developers")
@@ -100,7 +99,7 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
         if no_prompt:
             raise Exception("Existing file at output path! Repeat with flag --overwrite to replace file.")
         else:
-            if click.confirm(cal.echo_yellow("Existing file at output path will be written over! Continue?", echo=False)):
+            if click.confirm(click.style("Existing file at output path will be written over! Continue?",fg='bright_yellow',bold=True)):
                 pass
             else:
                 raise Exception("Existing file at output path!")
@@ -124,72 +123,20 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
             elif pick == "F" or pick == "filing":
                 table = "filing"
             else:
-                cal.echo_yellow("Invalid table selection!", echo=True)
-    '''
-    change = False
-
-    if show_options_menu and not no_prompt:
-        if not click.confirm("Continue with current settings?"):
-            change = True
-            cli.main(['alacorder', '--help'], standalone_mode=False)
-            p = click.prompt('\nEnter the <option> you would like to set, or type \'skip\' to start with current settings.')
-            if p == "count" or p == "-c" or p == "--count":
-                count = click.prompt("Set total case count to pull from input", type=int)
-            elif p == "skip":
-                pass
-            elif p == "overwrite" or p == "--overwrite" or p == "-o":
-                overwrite = click.prompt(
-                    "Should Alacorder OVERWRITE any existing files at output file paths? [y/N]", type=bool)
-            elif p == "log" or p == "--log" or p == "no-log" or p == "--no-log" or p == "nl" or p == "-nl" or p == "no log" or p == "-n":
-                log = click.prompt("Should Alacorder print logs to console? [y/N]", type=bool)
-            elif p == "no_prompt" or p == "--no-prompt" or p == "-np" or p == "np" or p == "p" or p == "-p":
-                no_prompt = click.prompt("Should Alacorder proceed without prompting for user input? [y/N]", type=bool)
-            elif p == "debug" or p == "--debug" or p == "-db" or p == "db" or p == "-d" or p == "d":
-                debug = click.prompt("Should Alacorder print detailed debug logs? [y/N]", type=bool)
-            elif p == "no_batch" or p == "--no-batch" or p == "-nb" or p == "nb" or p == "nobatch" or p == "no batch" or p == "-b" or p == "b":
-                no_batch = click.prompt("Should Alacorder process all cases in one batch? [y/N]", type=bool)
-            elif p == "compress" or p == "--compress" or p == "-zip" or p == "zip" or p == "-z" or p == "z":
-                compress = click.prompt("Should Alacorder compress exports? [y/N]", type=bool)
-            elif p == "table" or p == "--table" or p == "-t" or p == "t":
-                archive = False
-                pick = click.prompt(cal.pick_table_only())
-                if pick == "B" or pick == "cases":
-                    table = "cases"
-                elif pick == "C" or pick == "fees":
-                    table = "fees"
-                elif pick == "D" or pick == "charges":
-                    table = "charges"
-                elif pick == "E" or pick == "disposition":
-                    table = "disposition"
-                elif pick == "F" or pick == "filing":
-                    table = "filing"
-                else:
-                    cal.echo_yellow("Invalid table selection!", echo=True)
-    '''
-
+                click.secho("Invalid table selection!", fg='red', bold=True)
 
     # finalize config
     cf = cal.set(inputs, outputs, count=count, table=table, overwrite=overwrite, log=log, no_write=no_write, no_prompt=no_prompt, no_batch=no_batch, debug=debug, compress=compress)
 
-    if debug:
-        click.echo(cf)
-    if log:
-        click.echo(cf.ECHO)
 
     if cf.MAKE == "multiexport" and cf.TABLE == "all":
         o = cal.cases(cf)
-        cal.logdebug(cf, o[0].describe())
-        cal.logdebug(cf, o[1].describe())
-        cal.logdebug(cf, o[2].describe())
     if cf.TABLE == "fees":
         o = cal.fees(cf)
-        cal.logdebug(cf, o.describe())
     if cf.TABLE == "charges" or cf.TABLE == "disposition" or cf.TABLE == "filing":
         o = cal.charges(cf)
-        cal.logdebug(cf, o.describe())
     if cf.TABLE == "cases":
-        o = cal.caseinfo(cf)
-        cal.logdebug(cf, o.describe())
+        o = cal.cases(cf)
 
 @cli.command(help="Create full text archive from case PDFs")
 @click.option('--input-path', '-in', required=True, type=click.Path(), prompt=cal.title(), help="Path to input archive or PDF directory", show_choices=False)
@@ -203,7 +150,7 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
 @click.option('--no-write','-n', default=False, is_flag=True, help="Do not export to output path", hidden=True)
 @click.option('--no-prompt', default=False, is_flag=True, help="Skip user input / confirmation prompts")
 @click.option('--debug','-d', default=False, is_flag=True, help="Print extensive logs to console for developers")
-@click.option('--no-batch','-b', default=False, is_flag=True, help="Process all inputs as one batch")
+@click.option('--no-batch','-b', default=True, is_flag=True, help="Process all inputs as one batch")
 @click.version_option(package_name='alacorder', prog_name='ALACORDER', message='%(prog)s beta %(version)s')
 def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no_batch, no_prompt, debug, compress):
 
@@ -248,7 +195,7 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
         if no_prompt:
             raise Exception("Existing file at output path! Repeat with flag --overwrite to replace file.")
         else:
-            if click.confirm(cal.echo_yellow("Existing file at output path will be written over! Continue?", echo=False)):
+            if click.confirm("Existing file at output path will be written over! Continue?"):
                 pass
             else:
                 raise Exception("Existing file at output path!")
@@ -261,42 +208,10 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
         click.echo(cf.ECHO)
 
     o = cal.archive(cf)
-    cal.logdebug(cf, o.describe())
 
+# fetch
 
-
-    '''
-    if show_options_menu and not no_prompt:
-        if not click.confirm("Continue with current settings?"):
-            change = True
-            cli.main(['alacorder', '--help'], standalone_mode=False)
-            p = click.prompt('\nEnter the <option> you would like to set, or type \'skip\' to start with current settings.')
-            if p == "count" or p == "-c" or p == "--count":
-                count = click.prompt("Set total case count to pull from input", type=int)
-            elif p == "skip":
-                pass
-            elif p == "overwrite" or p == "--overwrite" or p == "-o":
-                overwrite = click.prompt(
-                    "Should Alacorder OVERWRITE any existing files at output file paths? [y/N]", type=bool)
-            elif p == "dedupe" or p == "--dedupe" or p == "ignore" or p == "--ignore":
-                dedupe = click.prompt("Should Alacorder remove duplicate cases from outputs? [y/N]", type=bool)
-            elif p == "log" or p == "--log" or p == "no-log" or p == "--no-log" or p == "nl" or p == "-nl" or p == "no log" or p == "-n":
-                log = click.prompt("Should Alacorder print logs to console? [y/N]", type=bool)
-            elif p == "no_prompt" or p == "--no-prompt" or p == "-np" or p == "np" or p == "p" or p == "-p":
-                no_prompt = click.prompt("Should Alacorder proceed without prompting for user input? [y/N]", type=bool)
-            elif p == "debug" or p == "--debug" or p == "-db" or p == "db" or p == "-d" or p == "d":
-                debug = click.prompt("Should Alacorder print detailed debug logs? [y/N]", type=bool)
-            elif p == "no_batch" or p == "--no-batch" or p == "-nb" or p == "nb" or p == "nobatch" or p == "no batch" or p == "-b" or p == "b":
-                no_batch = click.prompt("Should Alacorder process all cases in one batch? [y/N]", type=bool)
-            elif p == "compress" or p == "--compress" or p == "-zip" or p == "zip" or p == "-z" or p == "z":
-                compress = click.prompt("Should Alacorder compress exports? [y/N]", type=bool)
-        '''
-
-    # finalize config
-
-# SCRAPER
-
-@cli.command(help="Use headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE in an Excel spreadsheet to submit a list of queries for Alacorder to scrape.")
+@cli.command(help="Fetch cases from Alacourt.com with input query spreadsheet headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE.")
 @click.option("--input-path", "-in", "listpath", required=True, prompt="Path to query table", help="Path to query table/spreadsheet (.xls, .xlsx, .csv, .json)", type=click.Path())
 @click.option("--output-path", "-out", "path", required=True, prompt="PDF download path", type=click.Path(), help="Desired PDF output directory")
 @click.option("--customer-id", "-c","cID", required=True, prompt="Alacourt Customer ID", help="Customer ID on Alacourt.com")
@@ -309,9 +224,9 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
 @click.option("--no-update","-w", is_flag=True, default=False, help="Do not update query template after completion")
 @click.option("--ignore-complete","-g", is_flag=True, default=False, help="Ignore initial completion status in query template")
 @click.option("--debug","-d", is_flag=True, default=False, help="Print detailed runtime information to console")
-def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update, ignore_complete, debug):
+def fetch(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update, ignore_complete, debug):
     """
-    Use headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE in an Excel spreadsheet to submit a list of queries for Alacorder to scrape.
+    Use headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE in an Excel spreadsheet to submit a list of queries for Alacorder to fetch.
     
     USE WITH CHROME (TESTED ON MACOS) 
     KEEP YOUR COMPUTER POWERED ON AND CONNECTED TO THE INTERNET.
@@ -324,7 +239,7 @@ def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update,
         pwd (str): Alacourt.com Password
         qmax (int, optional): Max queries to pull from inputs
         qskip (int, optional): Skip top n queries in inputs
-        speed (int, optional): Scrape rate multiplier
+        speed (int, optional): Fetch rate multiplier
         no_log (bool, optional): Do not print logs to console
         no_update (bool, optional): Do not update input query file with completion status
         debug (bool, optional): Print detailed logs to console
@@ -332,14 +247,14 @@ def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update,
     Returns:
         [driver, query_out, query_writer]:
             driver[0]: Google Chrome WebDriver() object 
-            query_out[1]: (pd.Series) Scraper queue
+            query_out[1]: (pd.Series) Fetchr queue
             query_writer[2]: (pd.DataFrame) Updated input query file
     """
     if debug:
         sys.tracebacklimit = 10
     rq = cal.readPartySearchQuery(listpath, qmax, qskip, no_log)
 
-    query = pd.DataFrame(rq[0]) # for scraper - only search columns
+    query = pd.DataFrame(rq[0]) # for fetchr - only search columns
     query_writer = pd.DataFrame(rq[1]) # original sheet for write completion 
     incomplete = query.RETRIEVED_ON.map(lambda x: True if x == "" else False)
     query = query[incomplete]
@@ -361,11 +276,11 @@ def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update,
     login(driver, cID, uID, pwd, speed)
 
     if not no_log:
-        cal.echo_green("Authentication successful. Fetching cases via party search...")
+        click.secho("Authentication successful. Fetching cases via party search...",fg='bright_green',bold=True)
 
     for i, n in enumerate(query.index):
         if debug:
-            click.echo(driver.current_url)
+            click.secho(driver.current_url)
         if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
                 login(driver, cID, uID, pwd, speed, no_log)
         driver.implicitly_wait(4/speed)
@@ -375,7 +290,7 @@ def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update,
             query_writer['RETRIEVED_ON'][n] = str(math.floor(time.time()))
             query_writer['CASES_FOUND'][n] = "0"
             if not no_log:
-                click.echo(f"Found no results for query: {query.NAME[n]}")
+                click.secho(f"Found no results for query: {query.NAME[n]}")
             continue
         with click.progressbar(results, show_eta=False, label=f"#{n}: {query.NAME[n]}") as bar:
             for url in bar:
@@ -396,7 +311,7 @@ def login(driver, cID, username, pwd, speed, no_log=False, path=""):
         cID (str): Alacourt.com Customer ID
         username (str): Alacourt.com User ID
         pwd (str): Alacourt.com Password
-        speed (TYPE): Scrape rate multiplier
+        speed (TYPE): Fetch rate multiplier
         no_log (bool, optional): Do not print logs
         path (str, optional): Set browser download path 
     
@@ -450,7 +365,7 @@ def login(driver, cID, username, pwd, speed, no_log=False, path=""):
     driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
 
     if not no_log:
-        cal.echo_green("Successfully connected and logged into Alacourt!")
+        click.secho("Successfully connected and logged into Alacourt!",fg='bright_green', bold=True)
 
     driver.implicitly_wait(0.5/speed)
 
@@ -485,7 +400,7 @@ def party_search(driver, name = "", party_type = "", ssn="", dob="", county="",
         case_year (str, optional): YYYY
         filed_before (str, optional): M/DD/YYYY
         filed_after (str, optional): M/DD/YYYY
-        speed (int, optional): Scrape rate multiplier
+        speed (int, optional): Fetch rate multiplier
         no_log (bool, optional): Do not print logs.
         debug (bool, optional): Print detailed logs.
     
@@ -506,12 +421,12 @@ def party_search(driver, name = "", party_type = "", ssn="", dob="", county="",
         party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
     except selenium.common.exceptions.NoSuchElementException:
         if not no_log:
-            cal.echo_red("Connection error. Attempting reconnection...")
+            click.secho("Connection error. Attempting reconnection...", fg='red', bold=True)
         driver.refresh()
         driver.implicitly_wait(10/speed)
         party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
         if not no_log:
-            cal.echo_green("Successfully connected and logged into Alacourt!")
+            click.secho("Successfully connected and logged into Alacourt!", fg='bright_green', bold=True)
 
     # field search
 
